@@ -1,5 +1,5 @@
-activity_frequency_log <- function(eventlog) {
-	activity_frequency_case(eventlog) -> r
+activity_frequency_log <- function(log) {
+	activity_frequency_case(log) -> r
 	output <- summary_statistics(r$absolute)
 	attr(output, "raw") <- r
 	return(output)
