@@ -12,8 +12,8 @@ plot_activity_presence <- function(x, ...) {
 		labs(x = "Activity", y = "Relative Activity Presence") -> p
 
 
-	if(!is.null(attr(x, "groups"))) {
-		p <-	p + facet_grid(as.formula(paste(c(paste(attr(x, "groups"), collapse = "+"), "~." ), collapse = "")), scales = "free_y")
+	if(!is.null(mapping$groups)) {
+		p <-	p + facet_grid(as.formula(paste(c(paste(mapping$groups, collapse = "+"), "~." ), collapse = "")), scales = "free_y")
 	}
 
 	return(p)
