@@ -6,6 +6,7 @@ plot_throughput_time <- function(x, ...) {
 	level <- attr(x, "level")
 	units <- attr(x, "units")
 
+	y_lab <- glue("Throughput time (in {units})")
 
 	if(level == "log") {
 		attr(x, "raw") %>%
@@ -14,15 +15,15 @@ plot_throughput_time <- function(x, ...) {
 			theme_light() +
 			coord_flip() +
 			scale_y_continuous() +
-			labs(x = "", y = glue("Throughput time (in {units})")) -> p
+			labs(x = "", y = y_lab) -> p
 	}
 	else if(level == "case") {
 		x %>%
 			ggplot(aes_string(glue("reorder({mapping$case_id}, throughput_time)"), "throughput_time")) +
-			geom_col(aes(fill = throughput_time)) +
+			geom_col(aes(fill = as.numeric(throughput_time))) +
 			scale_fill_continuous_tableau(palette = "Blue", name = "Throughput Time") +
 			scale_y_continuous() +
-			labs(x = "Cases", y = glue("Throughput time (in {units})")) +
+			labs(x = "Cases", y = y_lab) +
 			theme_light() +
 			coord_flip() +
 			theme(axis.text.y = element_blank()) +
