@@ -4,8 +4,8 @@ resource_specialisation_activity <- function(log) {
 	relative <- NULL
 
 	log %>%
-		group_by(!!activity_id_(log), !!resource_id_(log)) %>%
-		#summarize() %>%
+		distinct(!!activity_id_(log), !!resource_id_(log)) %>%
+		group_by(!!activity_id_(log)) %>%
 		summarize(absolute = n()) %>%
 		mutate(relative = absolute/n_resources(log))
 }
