@@ -3,8 +3,8 @@ resource_specialisation_log <- function(log) {
 	freq <- NULL
 
 	log %>%
-		group_by(!!resource_id_(log), !!activity_id_(log)) %>%
-		#summarize() %>%
+		distinct(!!resource_id_(log), !!activity_id_(log)) %>%
+		group_by(!!resource_id_(log)) %>%
 		summarize(freq = n()) -> raw
 
 	raw %>%
